You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2016/05/20 23:52:06 UTC

svn commit: r1744817 - in /commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections: CollectionUtils.java comparators/FixedOrderComparator.java

Author: ggregory
Date: Fri May 20 23:52:06 2016
New Revision: 1744817

URL: http://svn.apache.org/viewvc?rev=1744817&view=rev
Log:
Standardize on US English spelling (recognised -> recognized.)

Modified:
    commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/CollectionUtils.java
    commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/comparators/FixedOrderComparator.java

Modified: commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/CollectionUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/CollectionUtils.java?rev=1744817&r1=1744816&r2=1744817&view=diff
==============================================================================
--- commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/CollectionUtils.java (original)
+++ commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/CollectionUtils.java Fri May 20 23:52:06 2016
@@ -888,7 +888,7 @@ public class CollectionUtils {
      * 
      * @param object  the object to get the size of
      * @return the size of the specified collection
-     * @throws IllegalArgumentException thrown if object is not recognised or null
+     * @throws IllegalArgumentException thrown if object is not recognized or null
      * @since Commons Collections 3.1
      */
     public static int size(Object object) {
@@ -940,7 +940,7 @@ public class CollectionUtils {
      * 
      * @param object  the object to get the size of, not null
      * @return true if empty
-     * @throws IllegalArgumentException thrown if object is not recognised or null
+     * @throws IllegalArgumentException thrown if object is not recognized or null
      * @since Commons Collections 3.2
      */
     public static boolean sizeIsEmpty(Object object) {

Modified: commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/comparators/FixedOrderComparator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/comparators/FixedOrderComparator.java?rev=1744817&r1=1744816&r2=1744817&view=diff
==============================================================================
--- commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/comparators/FixedOrderComparator.java (original)
+++ commons/proper/collections/branches/COLLECTIONS_3_2_X/src/java/org/apache/commons/collections/comparators/FixedOrderComparator.java Fri May 20 23:52:06 2016
@@ -172,7 +172,7 @@ public class FixedOrderComparator implem
         if (unknownObjectBehavior != UNKNOWN_AFTER 
             && unknownObjectBehavior != UNKNOWN_BEFORE 
             && unknownObjectBehavior != UNKNOWN_THROW_EXCEPTION) {
-            throw new IllegalArgumentException("Unrecognised value for unknown behaviour flag");    
+            throw new IllegalArgumentException("Unrecognized value for unknown behaviour flag");    
         }
         this.unknownObjectBehavior = unknownObjectBehavior;
     }
@@ -224,7 +224,7 @@ public class FixedOrderComparator implem
      * Compares two objects according to the order of this Comparator.
      * <p>
      * It is important to note that this class will throw an IllegalArgumentException
      * in the case of an unrecognised object. This is not specified in the 
      * Comparator interface, but is the most appropriate exception.
      * 
      * @param obj1  the first object to compare
@@ -224,7 +224,7 @@ public class FixedOrderComparator implem
      * <p>
      * It is important to note that this class will throw an IllegalArgumentException
-     * in the case of an unrecognised object. This is not specified in the 
+     * in the case of an unrecognized object. This is not specified in the 
      * Comparator interface, but is the most appropriate exception.
      * 